package edu.uwec.cs.wickmr.life.singleton;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/*
 * 
 * This is the main class of the application. 
 */
public class GameOfLifeUI extends JFrame implements GameConstants {
	protected final static Color DEFAULT_LIVE_COLOR = Color.RED;
	protected final static Color DEFAULT_DEAD_COLOR = Color.BLACK;
	protected GameOfLife game;
	protected GameOfLifePanel view;
	protected JPanel contentPane;
	protected JButton advanceButton;

	
	//	Build the appropriate instance of the World class and initialize the
	//  application frame.
	public GameOfLifeUI(String title, GameOfLife game)  {
		this(title, game, DEFAULT_LIVE_COLOR, DEFAULT_DEAD_COLOR);
	}
	
	public GameOfLifeUI(String title, GameOfLife game, Color liveColor, Color deadColor){
		super(title);
		this.game = game;
		view = new GameOfLifePanel(game, liveColor, deadColor);
		advanceButton = new JButton("Advance");
		contentPane = new JPanel();
		game.attach(this);
		initialize();

	}
	
	// Build the UI and set the "advance" button to cause the world object to 
	//  advance one generation.
	protected void initialize(){
		this.setSize(view.getWidth()+PAD_WIDTH, view.getHeight()+PAD_HEIGHT);
		contentPane.setLayout(new FlowLayout());
		contentPane.add(view);
		//contentPane.setBackground(Color.black);
		//contentPane.add(view2);
		contentPane.add(advanceButton);
		
		this.setContentPane(contentPane);
		this.setVisible(true);
		advanceButton.addActionListener( new ActionListener(){
			public void actionPerformed(ActionEvent e){
				game.advance();
			} } );
		this.setDefaultCloseOperation(DISPOSE_ON_CLOSE);
	}
	
	// Repaint the view to display the changes to the world.
	public void update(){
		repaint();
	}


}
